void Menu::initialize()
{
	gameDelay = 10;

	controller.size = 1;

	currentGame = gmMenu;

	elpased = millis();
}

void Menu::update()
{
	switch (currentGame)
	{
	case gmMenu:
		updateMenu();
		break;
	case gmPong:
		pong.update();
		break;
	case gmTedshow:
		tedShow.update();
		break;
	case gmSpaceInvaders:
		spaceInvaders.update();
		break;
	case gmSnake:
		snake.update();
		break;
	case gmBreakOut:
		breakout.update();
		break;
	case gmRacing:
		racing.update();
		break;
	}
}

void Menu::updateMenu()
{
	// find sprites offset according to potmeter reading
	int offset = map(analogRead(ControllerPotPin), 0, 1020, 0, width - 8);

	// display sprite from offset
	for (int y = 0; y < 8; y++)
	{
		for (int x = 0; x < 8; x++)
		{
			display.drawPixel(x, y, menuStrip[y][x + offset] == 1);
			//display.drawPixel(y, 7-x, menuStrip[y][x + offset] == 1);
		}
	}

	// read start button pressed
	if (controller.rightButtonPressed || controller.leftButtonPressed)
	{
		startGame(offset);
	}
}

void Menu::startGame(int offset)
{
	// Start selected game according to offset read in updateMenu() method
	// The currentGame enum determines which update method will be
	// called in the Menu::update method, which in turn is called in the 
	// loop method.

	if (between(offset, 0, 2))
	{
		currentGame = gmPong;
	    
		// new game animation
    	display.newGame();
		
		pong.play();
	}

	if (between(offset, 7, 9))
	{
		currentGame = gmTedshow;
	    
		// new game animation
    	display.newGame();
		
		tedShow.play();
	}

	if (between(offset, 15, 17))
	{
		currentGame = gmSpaceInvaders;
	    
		// new game animation
    	display.newGame();
		
		spaceInvaders.play();
	}

	if (between(offset, 23, 24))
	{    
		currentGame = gmSnake;
	    
		// new game animation
    	display.newGame();
		
		snake.play();
	}

	if (between(offset, 30, 33))
	{
		currentGame = gmBreakOut;

		// new game animation
		display.newGame(); 

		breakout.play();
	}

	if (between(offset, 40, 40))
	{
		currentGame = gmRacing;

		// new game animation
		display.newGame(); 

		racing.play();
	}
}

bool Menu::between(int val, int min, int max)
{
	return val >= min && val <= max;
}
